@@ -17,10 +17,10 @@ from autots.datasets import (
 from autots.evaluator.auto_ts import AutoTS
 from autots.tools.transform import GeneralTransformer, RandomTransform
 from autots.tools.shaping import long_to_wide
-from autots.tools.regressor import create_lagged_regressor
+from autots.tools.regressor import create_lagged_regressor, create_regressor
 from autots.evaluator.auto_model import model_forecast
 
-__version__ = '0.3.7'
+__version__ = '0.3.8'
 
 TransformTS = GeneralTransformer
 
